@@ -24,7 +24,7 @@ check_msg_time(data = aligned1, Msg = "VowelOnset")
 #  MSGTime <- check_msg_time(data = aligned1, Msg = "VowelOnset", ReturnData = TRUE)
 
 ## ---- eval= TRUE, echo=TRUE, results='asis'------------------------------
-aligned2 <- create_time_series(data = aligned1, Adj = 0)
+aligned2 <- create_time_series(data = aligned1, Adjust = 0)
 
 ## ---- eval= TRUE, echo=TRUE, results='asis'------------------------------
 check_time_series(data = aligned2)
